//-----------------------------------------------------------------------------
//  EDGE BeOS CD Handling Code
//-----------------------------------------------------------------------------
//
//  Copyright (c) 1999-2000  The EDGE Team.
//
//  This program is free software; you can redistribute it and/or
//  modify it under the terms of the GNU General Public License
//  as published by the Free Software Foundation; either version 2
//  of the License, or (at your option) any later version.
//
//  This program is distributed in the hope that it will be useful,
//  but WITHOUT ANY WARRANTY; without even the implied warranty of
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//  GNU General Public License for more details.
//
//  DESCRIPTION:
// 	This CD audio module uses the Linux ioctl()
// 	interface, to play audio CD's.
//
//-----------------------------------------------------------------------------
//
// -ACB- 2000/03/17 Based Heavily on Udo Munks CD Handling Code from his
//                  excellent Port of the Doom Engine for X (every flavour
//                  known to man) - XDoom.
// -DEL- 2000/07/03 Rewritten based on SDL CD handling still not tested 
//                  as the SDL CD test app doesn't work on my system
//                  someone else will need to test this works if they can 
//                  get the SDL cd test app to work. 
// -DEL- 2000/07/03  TODO - volume control ( I_CDSetVolume ) 
#include <SDL/SDL.h>
#include "i_defs.h"
#include "b_sysinc.h"



static SDL_CD *cdrom;				

//
// I_StartupCD
//
// This routine checks attempts to init the CDROM device. Returns true is successful
//
boolean_t I_StartupCD(void)
{
  L_WriteDebug("I_StartupCD: Initializing...\n");
  if ( SDL_CDNumDrives() > 0 )
  { 
    cdrom = SDL_CDOpen(0); 
    if ( cdrom == NULL ) 
    {
      I_PostMusicError("I_StartupCD: Can't open CDROM device");
      return false;
    }
  } 
  L_WriteDebug("I_StartupCD: CD Init OK\n");
  return true;	
}

//
// I_CDStartPlayback
//
// Attempts to play CD track 'tracknum', returns true on success.
//
boolean_t I_CDStartPlayback(int tracknum)
{
  if ( CD_INDRIVE(SDL_CDStatus(cdrom)) )
  { 
    SDL_CDPlayTracks(cdrom, tracknum, 0, tracknum+1, 0);
    return true; 
  } 
  else 
    return false;
}

//
// I_CDPausePlayback
//
// Paused the playing CD
//
void I_CDPausePlayback(void)
{
  SDL_CDPause(cdrom);
}  

// I_CDresumePlayback
//
// Resumes the paused CD
//
void I_CDResumePlayback(void)
{
  SDL_CDResume(cdrom);
}

//
// XDoom calls this function to stop playing the current song.
//
void I_CDStopPlayback(void)
{
  SDL_CDStop(cdrom);
}

//
// I_CDSetVolume
//
// Sets the CD Volume
//
void I_CDSetVolume(int vol)
{
/*  if ((vol >= 0) && (vol <= 15))
  {
    volume.channel0 =  vol * 255 / 15;
    volume.channel1 =  vol * 255 / 15;
    volume.channel2 =  0;
    volume.channel3 =  0;
    ioctl(fd, CDROMVOLCTRL, &volume);
  } */
}

//
// I_CDFinished
//
// Has the CD Finished
//
boolean_t I_CDFinished(void)
{
  return (!SDL_CDStatus == CD_PLAYING);
}

//
// I_ShutdownCD
//
// Closes the cdrom device
//
void I_ShutdownCD()
{
  SDL_CDClose(cdrom);
}
