//----------------------------------------------------------------------------
//  EDGE Incomplete Libc Compensation Library
//----------------------------------------------------------------------------
// 
//  Copyright (c) 2000  The EDGE Team.
// 
//  This program is free software; you can redistribute it and/or
//  modify it under the terms of the GNU General Public License
//  as published by the Free Software Foundation; either version 2
//  of the License, or (at your option) any later version.
//
//  This program is distributed in the hope that it will be useful,
//  but WITHOUT ANY WARRANTY; without even the implied warranty of
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//  GNU General Public License for more details.
//
//----------------------------------------------------------------------------
// This file contains replacements for standard functions, which are not ANSI
// but are included in most standard C libraries anyways. A function will
// be taken from this file if it doesn't exist in libc.
//
// If a function listed here is supported by the libc of your system,
// enable the libc version by #defining the EDGE function name as the libc
// one in i_defs.h. E.g.,
// #define L_StrUpr(str) strupr(str)
// can be done on systems that support strupr.

#include "../i_defs.h"
#include "../l_epi.h"

#ifndef L_StrUpr
//
// L_StrUpr
//
// Replacement for strupr, which turns all characters of str to uppercase.
void L_StrUpr(char *str)
{
  if (str == NULL)
    return;

  while (*str)
  {
    *str = toupper(*str);
    str++;
  }
}
#endif

#ifndef L_StrCaseCmp
//
// L_StrCaseCmp
//
// Replacement for strcasecmp or stricmp, which performs a case-insensitive
// comparison between the two strings.
int L_StrCaseCmp(const char *s1, const char *s2)
{
  int count;

  count = 0;

  while(!(s1[count] == '\0' && s2[count] == '\0'))
  {
    if ((s1[count]&0xDF) != (s2[count]&0xDF))
      return ((s1[count]&0xDF)-(s2[count]&0xDF));

    count++;
  }

  return 0;
}
#endif

#ifndef L_StrNCaseCmp
//
// L_StrNCaseCmp
//
// Replacement for strncasecmp or strnicmp, which performs a case-insensitive
// comparison between up to max characters of the two strings.
int L_StrNCaseCmp(const char *s1, const char *s2, int max)
{
  int count;

  count = 0;

  while(count < max)
  {
    if ((s1[count]&0xDF) != (s2[count]&0xDF))
      return ((s1[count]&0xDF)-(s2[count]&0xDF));

    if (s1[count] == '\0' && s2[count] == '\0')
      return 0;

    count++;
  }

  return 0;
}
#endif
